Modules
- Color types for used for being generic over the color
Commandline argument parser- Different display styles (strikethrough, bold, etc.)
Macros
- Create an
Argfrom a usage string. - The main macro provided by this crate. See crate documentation for more information.
- Requires
cargofeature flag to be enabled. - Select a
ValueParserimplementation from the intended type
Structs
- The abstract representation of a command line argument. Used to set all the options and relationships that define a valid argument for the program.
- Family of related arguments.
- Container for parse results.
- Transparent wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the background color. Recommended to be constructed using
OwoColorize. - Wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the background color. Is not recommended unless compile-time coloring is not an option.
- A wrapper type which applies both a foreground and background color
- Build a command-line interface.
- Transparent wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the foreground color. Recommended to be constructed using
OwoColorize. - Wrapper around a type which implements all the formatters the wrapped type does, with the addition of changing the foreground color. Is not recommended unless compile-time coloring is not an option.
- An error for when the color can not be parsed from a string at runtime
- Available RGB colors for use with
OwoColorize::colororOwoColorize::on_color - A pre-computed style that can be applied to a struct using [
OwoColorize::style]. - A wrapper type which applies a
Stylewhen displaying the inner type - A collection of
Styleditems that are displayed in such a way as to minimize the amount of characters that are written when displayed.
Enums
- Available standard ANSI colors for use with
OwoColorize::colororOwoColorize::on_color - Behavior of arguments when they are encountered while parsing
- Represents the color preferences for program output
- Available CSS colors for use with
OwoColorize::colororOwoColorize::on_color - An enum describing runtime-configurable colors
- A runtime-configurable text effect for use with
Style - Provide shell with hint on how to complete an argument.
- Available Xterm colors for use with
OwoColorize::colororOwoColorize::on_color
Traits
- Parse a set of arguments into a user-defined container.
- A trait for describing a type which can be used with
FgColorDisplayorBgColorDisplay - Create a
Commandrelevant for a user-defined container. - A trait describing a runtime-configurable color which can displayed using
FgDynColorDisplayorBgDynColorDisplay. If your color will be known at compile time it is recommended you avoid this. - Converts an instance of
ArgMatchesto a user-defined container. - Parse command-line arguments into
Self. - Parse a sub-command into a user-defined enum.
- Parse arguments into enums.
Functions
- Helper to create
Styles more ergonomically
Type Aliases
- Command Line Argument Parser Error